@@ -1,4 +1,4 @@
-use pulldown_cmark::{html, Options, Parser};
+use pulldown_cmark::{html, Event, Options, Parser, Tag};
 
 /**
  * https://docs.rs/pulldown-cmark/latest/pulldown_cmark/#example
@@ -11,7 +11,17 @@ pub fn parse_md_to_html(markdown_input: &str) -> String {
     options.insert(Options::ENABLE_TASKLISTS);
     options.insert(Options::ENABLE_SMART_PUNCTUATION);
     let parser = Parser::new_ext(markdown_input, options);
-
+    let parser = parser.map(|event| match event {
+        Event::Start(tag) => {
+            if let Tag::Image(a, url, b) = tag {
+                let u = url.replace("../image", "/image");
+                Event::Start(Tag::Image(a, u.into(), b))
+            } else {
+                Event::Start(tag)
+            }
+        }
+        _ => event,
+    });
     // Write to String buffer.
     let mut html_output = String::new();
     html::push_html(&mut html_output, parser);
